Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(178)

Unified Diff: ui/app_list/pagination_model.h

Issue 10890049: app_list: Touch scroll and animation improvement. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ui/app_list/contents_view.cc ('k') | ui/app_list/pagination_model.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/app_list/pagination_model.h
diff --git a/ui/app_list/pagination_model.h b/ui/app_list/pagination_model.h
index 39f88e0636a7110d279b77572ab93a14ccb95114..89b057ae7a14a6ff24f280b41306ef5884ee99ee 100644
--- a/ui/app_list/pagination_model.h
+++ b/ui/app_list/pagination_model.h
@@ -60,7 +60,6 @@ class APP_LIST_EXPORT PaginationModel : public ui::AnimationDelegate {
void SetTransition(const Transition& transition);
void SetTransitionDuration(int duration_ms);
- void ResetTransitionAnimation();
// Starts a scroll transition. If there is a running transition animation,
// cancels it but keeps the transition info.
@@ -71,9 +70,9 @@ class APP_LIST_EXPORT PaginationModel : public ui::AnimationDelegate {
// to next page (moving pages to the left).
void UpdateScroll(double delta);
- // Ends the current scroll transition. If transition progress > 0.5, finishes
- // it. Otherwise, reverses it.
- void EndScroll();
+ // Finishes the current scroll transition if |cancel| is false. Otherwise,
+ // reverses it.
+ void EndScroll(bool cancel);
void AddObserver(PaginationModelObserver* observer);
void RemoveObserver(PaginationModelObserver* observer);
@@ -108,6 +107,7 @@ class APP_LIST_EXPORT PaginationModel : public ui::AnimationDelegate {
void StartTranstionAnimation(int target_page);
void CreateTransitionAnimation();
+ void ResetTransitionAnimation();
// ui::AnimationDelegate overrides:
virtual void AnimationProgressed(const ui::Animation* animation) OVERRIDE;
« no previous file with comments | « ui/app_list/contents_view.cc ('k') | ui/app_list/pagination_model.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698